****************************************************************************
* Bodyweight and human capital development: Assessing the impact of obesity	
* 		on socioemtional skills during childhood in Chile.
* Do file to replicate the main results of article
* By: Mauricio Sarrias
*****************************************************************************

** Set globals ***
global dir   "/Users/mauriciosarrias/Dropbox/work/Health/Child development/Socioemotional-Obesity/Replication"
global out "/Users/mauriciosarrias/Dropbox/work/Health/Child development/Socioemotional-Obesity/Replication/"

* Open data set
use "$dir/elpi_ehb.dta", clear

*==================================================*
* I. Table 1: Summary statistics 
*==================================================*

xtset folio wave

*Globals for controls: Just potentially exogenous variables
global child "age_eval c.age_eval#c.age_eval i.sexchild nolders nyounger" 
global house "i.region hsize"
global care  "i.hhead i.civil2 age_care"


** Gen flag sample
reg lcbcl_t i.wave $child $house $care zbmi_child Lbmi_care
gen flag1 = 1 if e(sample)

tabulate civil2, gen(cv)
global children "cbcl_t weight height bmi_child zbmi_child T_95 age_eval nolders nyounger " 
global household "hsize"
global maternal "age_care hhead cv*"
global instr    "Lbmi_care"


eststo clear 
estpost tabstat $children $household $maternal $instr if flag1 == 1, by(sexchild) nototal columns(statistics) statistics(mean sd count)
esttab . using "$out/table_sum.tex", replace ///
		cells("mean(fmt(2)) sd(fmt(2)) count(fmt(0))") ///
          collabels("\multicolumn{1}{c}{Mean}" "\multicolumn{1}{c}{SD}" "\multicolumn{1}{c}{N}", span ) ///
		  title("Summary statistics\label{tab:summary}") ///
		  eqlabels("Girls" "Boys", pattern(1 0 0 1 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
		 coeflabels(cbcl_t  "CBCL-test score" ///
		          weight "Weight" ///
				  height "Height" ///
				  bmi_child   "Child's BMI" ///
				  zbmi_child  "Child's z-BMI" ///
				  T_95  "Obese" ///
				  age_eval "Child's age in months" ///
				  nolders "Number of older siblings" ///
				  nyounger "Number of younger siblings" ///
				  hsize "Household size" ///
				  age_care "Age (in years)" ///
				  cv1 "Married" ///
				  cv2 "Cohabitating" ///
				  cv3 "Separated/divorce" ///
				  cv4 "Single" ///
				  hhead "Household head" ///
				  cv5 "Widowed" ///
				  Lbmi_care "Mother's BMI in previous period") ///
		refcat(cbcl_t  "\textbf{Children covariates:}" ///
			   age_care  "\textbf{Mother's covariates:}" ///
			   Lzbmi_care "\textbf{Instrument:}", nolabel) ///
		  unstack nonumbers compress nogap booktabs nolabel longtable

*===========================================================*
* Table 2: Benchmark results for the relationship between
*.         socioemotional development and bodyweight
*===========================================================*

xtset folio wave

* Globals for controls: Just potentially exogenous variables
global child "age_eval c.age_eval#c.age_eval nolders nyounger" 
global house "i.region hsize"
global care  "i.hhead i.civil2 age_care"

* Gen flag for sample used
reg lcbcl_t i.wave $child $house $care zbmi_child L.zbmi_care
gen flag2 = 1 if e(sample)

* Unconditional OLS
est clear
local se vce(cluster folio)
foreach c of numlist 0 1 {
	eststo: reg lcbcl_t zbmi_child    i.wave if flag2 == 1 & sexchild == `c', `se'
	eststo: reg lcbcl_t T_95          i.wave if flag2 == 1 & sexchild == `c', `se'
	eststo: reg lcbcl_t weight height i.wave if flag2 == 1 & sexchild == `c', `se'
}
esttab using "$out/cbcl-full-balanced.tex", replace f ///
	b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) ///
	keep(zbmi_child T_95 weight height) coeflabel(zbmi_child "z-BMI" T_95 "Obese" weight "Weight" height "Height") ///
	substitute(\_ _) ///
	booktabs nonotes collabels(none) alignment(D{.}{.}{-1}) longtable nolines posthead(\hline \textbf{Panel A: Unconditional OLS} \\) compress nogap nodepvar nomtitle ///
	stats(N, fmt(%9.0gc) label("N")) ///
   mgroups("Girls" "Boys", pattern(1 0 0 1 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
		
* Conditional OLS
est clear
local se vce(cluster folio)
foreach c of numlist 0 1 {
	eststo: reg lcbcl_t zbmi_child    i.wave $child $house $care if flag2 == 1 & sexchild == `c', `se'
	eststo: reg lcbcl_t T_95          i.wave $child $house $care if flag2 == 1 & sexchild == `c', `se'
	eststo: reg lcbcl_t weight height i.wave $child $house $care if flag2 == 1 & sexchild == `c', `se'
}
esttab using "$out/cbcl-full-balanced.tex", append f ///
	b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) ///
	keep(zbmi_child T_95 weight height) coeflabel(zbmi_child "z-BMI" T_95 "Obese" weight "Weight" height "Height") ///
	substitute(\_ _) ///
	label booktabs nonotes collabels(none) alignment(D{.}{.}{-1}) longtable nomtitle nolines nonum posthead(\hline \textbf{Panel B: OLS + Controls} \\)  compress nogap ///
	stats(N, fmt(%9.0gc) label("N")) 
			
* IV
est clear
local se vce(cluster folio)
local z Lbmi_care
foreach c of numlist 0 1 {
	eststo: ivregress 2sls lcbcl_t        i.wave $child $house $care (zbmi_child = `z')	if flag2 == 1 & sexchild == `c', `se' first
	estat firststage, all
	mat fstat = r(singleresults)
	estadd scalar weak_F = fstat[1,4]
	estat endogenous
	estadd scalar Fendo  = r(regF)
	estadd scalar pFendo = r(p_regF)
	eststo: ivregress 2sls lcbcl_t        i.wave $child $house $care (T_95 = `z')		if flag2 == 1 & sexchild == `c', `se' first
	estat firststage, all
	mat fstat = r(singleresults)
	estadd scalar weak_F = fstat[1,4]
	estat endogenous
	estadd scalar Fendo  = r(regF)
	estadd scalar pFendo = r(p_regF)
	eststo: ivregress 2sls lcbcl_t height i.wave $child $house $care (weight = `z')		if flag2 == 1 & sexchild == `c', `se' first
	estat firststage, all
	mat fstat = r(singleresults)
	estadd scalar weak_F = fstat[1,4]
	estat endogenous
	estadd scalar Fendo  = r(regF)
	estadd scalar pFendo = r(p_regF)
}	
esttab using "$out/cbcl-full-balanced.tex", append f ///
	b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) ///
    keep(zbmi_child T_95 weight height) coeflabel(zbmi_child "z-BMI" T_95 "Obese" weight "Weight" height "Height") ///
	substitute(\_ _) ///
	label booktabs nonotes collabels(none) alignment(D{.}{.}{-1}) longtable nomtitle nolines nonum posthead(\hline \textbf{Panel C: IV} \\)  compress nogap ///
	stats(weak_F N, fmt(%-9.3f %9.0gc) label("F first-stage" "N"))
	
*==================================================*
* Figure 1: Predicted relationship between children's bodyweight
*           and lagged mother's BMI
*==================================================*

*Globals for controls: Just potentially exogenous variables
global child "age_eval c.age_eval#c.age_eval nolders nyounger" 
global house "i.region hsize"
global care  "i.hhead i.civil2 age_care"

reg bmi_child Lbmi_care c.Lbmi_care#c.Lbmi_care i.wave $child $house $care if sexchild == 1 & flag2 == 1
eststo boys: margins, at(Lbmi_care=(15(5)55)) post

reg bmi_child Lbmi_care c.Lbmi_care#c.Lbmi_care i.wave $child $house $care if sexchild == 0 & flag2 == 1
eststo girls: margins, at(Lbmi_care=(15(5)55)) post

coefplot boys girls, vertical recast(connected) ///
      scheme(s1mono) xtitle("Mother's lagged BMI") ytitle("Predicted child's BMI") nolabel ///
	  xlabel(1 "15" 2 "20" 3 "25" 4 "30" 5 "35" 6 "40" 7 "45" 8 "50" 9 "55") title ("BMI")
graph save "$out/mon-bmi", replace

reg zbmi_child Lbmi_care c.Lbmi_care#c.Lbmi_care  i.wave $child $house $care if sexchild == 1 & flag2 == 1
eststo boys: margins, at(Lbmi_care=(15(5)55)) post

reg zbmi_child Lbmi_care c.Lbmi_care#c.Lbmi_care  i.wave $child $house $care if sexchild == 0 & flag2 == 1
eststo girls: margins, at(Lbmi_care=(15(5)55)) post

coefplot boys girls, vertical recast(connected) ///
      scheme(s1mono) xtitle("Mother's lagged BMI") ytitle("Predicted child's z-BMI") nolabel ///
	  xlabel(1 "15" 2 "20" 3 "25" 4 "30" 5 "35" 6 "40" 7 "45" 8 "50" 9 "55") title ("z-BMI")
graph save "$out/mon-zbmi", replace


probit T_95  Lbmi_care c.Lbmi_care#c.Lbmi_care i.wave $child $house $care if sexchild == 1 & flag2 == 1
eststo boys: margins, at(Lbmi_care=(15(5)55)) post

probit T_95  Lbmi_care c.Lbmi_care#c.Lbmi_care i.wave $child $house $care if sexchild == 0 & flag2 == 1
eststo girls: margins, at(Lbmi_care=(15(5)55)) post

coefplot boys girls, vertical recast(connected) ///
      scheme(s1mono) xtitle("Mother's lagged BMI") ytitle("Predicted probability of being obese") nolabel ///
	  xlabel(1 "15" 2 "20" 3 "25" 4 "30" 5 "35" 6 "40" 7 "45" 8 "50" 9 "55") title ("Obesity")
graph save "$out/mon-obesity", replace

reg weight height Lbmi_care c.Lbmi_care#c.Lbmi_care i.wave $child $house $care if sexchild == 1 & flag2 == 1
eststo boys: margins, at(Lbmi_care=(15(5)55)) post

reg weight height Lbmi_care c.Lbmi_care#c.Lbmi_care i.wave $child $house $care if sexchild == 0 & flag2 == 1
eststo girls: margins, at(Lbmi_care=(15(5)55)) post

coefplot boys girls, vertical recast(connected) ///
      scheme(s1mono) xtitle("Mother's lagged BMI") ytitle("Predicted child's weight") nolabel ///
	  xlabel(1 "15" 2 "20" 3 "25" 4 "30" 5 "35" 6 "40" 7 "45" 8 "50" 9 "55") title ("Weight")
graph save "$out/mon-weight", replace

gr combine "$out/mon-bmi" "$out/mon-zbmi" "$out/mon-obesity" "$out/mon-weight", col(2) iscale(0.5)
graph export "$out/monotonicity.eps", replace

*==================================================*
* Table 3: Pooled IV-estimates with gender interactions
*==================================================*

*Globals for controls: Just potentially exogenous variables
global child "age_eval c.age_eval#c.age_eval nolders nyounger" 
global house "i.region hsize"
global care  "i.hhead i.civil2 age_care"

est clear
eststo m1: ivreg2 lcbcl_t i.wave $child $house $care sexchild        (zbmi_child c.zbmi_child#sexchild = Lbmi_care c.Lbmi_care#sexchild) if flag2 == 1, cluster(folio)
eststo m2: ivreg2 lcbcl_t i.wave $child $house $care i.sexchild 	 (i.T_95 i.T_95#i.sexchild = Lbmi_care c.Lbmi_care#i.sexchild)       if flag2 == 1, cluster(folio)
eststo m3: ivreg2 lcbcl_t i.wave $child $house $care sexchild height (weight c.weight#sexchild = Lbmi_care c.Lbmi_care#sexchild)         if flag2 == 1, cluster(folio)
esttab m1 m2 m3 using "$out/interactions.tex", replace ///
	keep(zbmi_child 1.sexchild#c.zbmi_child 1.T_95 1.T_95#1.sexchild weight 1.sexchild#c.weight) ///
	coeflabel(zbmi_child "z-BMI" 1.T_95 "Obese" weight "Weight" 1.sexchild#c.zbmi_child "z-BMI$\times\$ boy" 1.T_95#1.sexchild "Obese$\times\$ boy" 1.sexchild#c.weight "Weight$\times\$ boy") ///
	b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) ///
	booktabs nonotes collabels(none) alignment(D{.}{.}{-1}) longtable compress nogap nodepvar nomtitle  ///
	stats(N widstat, ///
	fmt(%9.0gc %-9.3f) labels("N" "F-stat")) ///
	title("Pooled IV-estimates with gender interactions \label{tab:interactions}")
	


*=====================================================================*
* Table 4: Sensitivity analysis to additional controls: IV-estimates
*=====================================================================*

*Globals for controls: Just potentially exogenous variables
global child "age_eval c.age_eval#c.age_eval nolders nyounger" 
global house "i.region hsize"
global care  "i.hhead i.civil2 age_care"

reg lcbcl_t i.wave $child $house $care cesd10_int dep_post lninc sch_care smoke drink2 drug2 zbmi_child L.bmi_care
gen flag3 = 1 if e(sample)

*** Additional covariates
local sample flag3 == 1
local se vce(cluster folio)
local base i.wave $child $house $care
local x zbmi_child 
local z Lbmi_care
est clear
foreach c of numlist 0 1 {
	eststo: ivregress 2sls lcbcl_t  `base' (`x' = `z')     if `sample' & sexchild == `c', `se' first
	scalar base = _b[`x']
	estat firststage, all
	mat fstat = r(singleresults)
	estadd scalar weak_F = fstat[1,4]
	estat endogenous
	estadd scalar Fendo  = r(regF)
	estadd scalar pFendo = r(p_regF)
	
	eststo: ivregress 2sls lcbcl_t  `base' cesd10_int dep_post (`x' = `z')     if `sample' & sexchild == `c', `se' first
	estat firststage, all
	mat fstat = r(singleresults)
	estadd scalar weak_F = fstat[1,4]
	estat endogenous
	estadd scalar Fendo  = r(regF)
	estadd scalar pFendo = r(p_regF)
	scalar new = _b[`x']
	estadd scalar share = (base - new) / base * 100

	
	eststo: ivregress 2sls lcbcl_t  `base' smoke drink2 drug2 (`x' = `z')     if `sample' & sexchild == `c', `se' first
	estat firststage, all
	mat fstat = r(singleresults)
	estadd scalar weak_F = fstat[1,4]
	estat endogenous
	estadd scalar Fendo  = r(regF)
	estadd scalar pFendo = r(p_regF)
	scalar new = _b[`x']
	estadd scalar share = (base - new) / base * 100

	
	eststo: ivregress 2sls lcbcl_t  `base' lninc sch_care (`x' = `z')     if `sample' & sexchild == `c', `se' first
	estat firststage, all
	mat fstat = r(singleresults)
	estadd scalar weak_F = fstat[1,4]
	estat endogenous
	estadd scalar Fendo  = r(regF)
	estadd scalar pFendo = r(p_regF)
	scalar new = _b[`x']
	estadd scalar share = (base - new) / base * 100

	
	eststo: ivregress 2sls lcbcl_t  `base' smoke drink2 drug2 lninc sch_care cesd10_int dep_post (`x' = `z')     if `sample' & sexchild == `c', `se' first
	estat firststage, all
	mat fstat = r(singleresults)
	estadd scalar weak_F = fstat[1,4]
	estat endogenous
	estadd scalar Fendo  = r(regF)
	estadd scalar pFendo = r(p_regF)
	scalar new = _b[`x']
	estadd scalar share = (base - new) / base * 100

}	
esttab  using "$out/robust.tex", replace f ///
	b(%-9.3f) se(%-9.3f) star(* 0.10 ** 0.05 *** 0.01) ///
    keep(zbmi_child cesd10_int dep_post lninc sch_care smoke drink2 drug2) ///
	coeflabel(zbmi_child "z-BMI" cesd10_int "Actual depression" dep_post "Post-partum depression" lninc "ln(household income)" sch_care "Mother's education" smoke "Smoked during pregnancy" drink2 "Drunk during pregnancy" drug2 "Used drugs during pregnancy") ///
	substitute(\_ _) ///
	booktabs nonotes collabels(none) alignment(D{.}{.}{-1}) longtable nolines posthead(\hline \textbf{Panel A: z-BMI} \\) compress nogap nodepvar nomtitle ///
	stats(weak_F share N, fmt(%-9.3f %-9.0f %9.0gc) label("F first-stage" "\shortstack[l]{\% Reduction \\ in bodyweight \\ coefficient}" "N")) ///
   mgroups("Girls" "Boys", pattern(1 0 0 0 0 1 0 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))

local sample flag3 == 1
local se vce(cluster folio)
local base i.wave $child $house $care
local x T_95 
local z Lbmi_care
est clear
foreach c of numlist 0 1 {
	eststo: ivregress 2sls lcbcl_t  `base' (`x' = `z')     if `sample' & sexchild == `c', `se' first
	scalar base = _b[`x']
	estat firststage, all
	mat fstat = r(singleresults)
	estadd scalar weak_F = fstat[1,4]
	estat endogenous
	estadd scalar Fendo  = r(regF)
	estadd scalar pFendo = r(p_regF)
	
	eststo: ivregress 2sls lcbcl_t  `base' cesd10_int dep_post (`x' = `z')     if `sample' & sexchild == `c', `se' first
	estat firststage, all
	mat fstat = r(singleresults)
	estadd scalar weak_F = fstat[1,4]
	estat endogenous
	estadd scalar Fendo  = r(regF)
	estadd scalar pFendo = r(p_regF)
    scalar new = _b[`x']
	estadd scalar share = (base - new) / base * 100
	
	eststo: ivregress 2sls lcbcl_t  `base' smoke drink2 drug2 (`x' = `z')     if `sample' & sexchild == `c', `se' first
	estat firststage, all
	mat fstat = r(singleresults)
	estadd scalar weak_F = fstat[1,4]
	estat endogenous
	estadd scalar Fendo  = r(regF)
	estadd scalar pFendo = r(p_regF)
	scalar new = _b[`x']
	estadd scalar share = (base - new) / base * 100
	
	eststo: ivregress 2sls lcbcl_t  `base' lninc sch_care (`x' = `z')     if `sample' & sexchild == `c', `se' first
	estat firststage, all
	mat fstat = r(singleresults)
	estadd scalar weak_F = fstat[1,4]
	estat endogenous
	estadd scalar Fendo  = r(regF)
	estadd scalar pFendo = r(p_regF)
	scalar new = _b[`x']
	estadd scalar share = (base - new) / base * 100
	
	eststo: ivregress 2sls lcbcl_t  `base' smoke drink2 drug2 lninc sch_care cesd10_int dep_post (`x' = `z')     if `sample' & sexchild == `c', `se' first
	estat firststage, all
	mat fstat = r(singleresults)
	estadd scalar weak_F = fstat[1,4]
	estat endogenous
	estadd scalar Fendo  = r(regF)
	estadd scalar pFendo = r(p_regF)
	scalar new = _b[`x']
	estadd scalar share = (base - new) / base * 100
}
esttab using "$out/robust.tex", append f ///
	b(%-9.3f) se(%-9.3f) star(* 0.10 ** 0.05 *** 0.01) ///
    keep(T_95 cesd10_int dep_post lninc sch_care smoke drink2 drug2) ///
	coeflabel(T_95 "Obesity" cesd10_int "Actual depression" dep_post "Post-partum depression" lninc "ln(household income)" sch_care "Mother's education" smoke "Smoked during pregnancy" drink2 "Drunk during pregnancy" drug2 "Used drugs during pregnancy") ///
	substitute(\_ _) ///
	label booktabs nonotes collabels(none) alignment(D{.}{.}{-1}) longtable nomtitle nolines nonum posthead(\hline \textbf{Panel B: Obesity} \\)  compress nogap ///
	stats(weak_F share N, fmt(%-9.3f %-9.0f %9.0gc) label("F first-stage" "\shortstack[l]{\% Reduction \\ in bodyweight \\ coefficient}" "N"))  
		  
*==================================================*
* Figures 3 and 4: Bound estimates
*==================================================*

* drop point* lCI uCI estimator LB* UB* lCInevo* uCInevo*
gen point = .
gen estimator = .
gen lCI =. 
gen uCI =. 
gen LB = .
gen UB = .
gen lCInevo =. 
gen uCInevo =. 
gen age2 = age_eval * age_eval 

xi: reg lcbcl_t $child $house $care i.wave 
global contr "age_eval age2 _Iwave_2  nolders nyounger _Iregion* hsize _Ihhead* _Icivil* age_care cesd10_int dep_post lninc sch_care smoke drink2 drug2"

* Negative of the instrument
gen nLbmi_care  = Lbmi_care * -1

drop point lCI uCI estimator LB* UB* lCInevo* uCInevo*
gen point = .
gen estimator = .
gen lCI =. 
gen uCI =. 
gen LB = .
gen UB = .
gen lCInevo =. 
gen uCInevo =. 

* Results for z-BMI
local contr $contr
local sample flag3 == 1
local se cluster folio
local x zbmi_child
local z nLbmi_care
local j = 1

foreach c of numlist 0 1 {
	* OLS 
	reg    lcbcl_t `contr' `x' if `sample' & sexchild == `c', vce(`se')
	local beta    		= _b[`x']
	local lCI     		= _b[`x']+invnormal(0.025)*_se[`x']
	local uCI     		= _b[`x']+invnormal(0.975)*_se[`x']
	replace point 		= `beta' in `j'
	replace lCI   		= `lCI'  in `j'
	replace uCI       	= `uCI'  in `j'
	replace estimator	= `j' in `j'
	local ++j
	
	* IV
	ivregress 2sls  lcbcl_t `contr' (`x' = `z')  if `sample' & sexchild == `c',  vce(`se')
	local betaiv = _b[`x']
	local lCIiv  = _b[`x']+invnormal(0.025)*_se[`x']
	local uCIiv  = _b[`x']+invnormal(0.975)*_se[`x']
	replace point = `betaiv' in `j'
	replace lCI   = `lCIiv'  in `j'
	replace uCI   = `uCIiv'  in `j'
	replace estimator = `j' in `j'
	local ++j
    
	* N&R no A4
    imperfectiv lcbcl_t `contr'  (`x' = `z')   if `sample' & sexchild == `c', vce(`se')  noassumption4
	matrix LRbounds = e(LRbounds)
	local LBci = LRbounds[1, 1]
	local LB   = LRbounds[1, 2]
	local UB   = LRbounds[1, 3]
	local UBci = LRbounds[1, 4]
	replace lCI   = `LBci'  in `j'
	replace uCI   = `UBci'  in `j'
	replace LB = `LB' in `j'
	replace UB = `UB' in `j'
	replace estimator = `j' in `j'
	local ++j
    
	* NR with A4
	imperfectiv lcbcl_t `contr'  (`x' = `z')   if `sample' & sexchild == `c', vce(`se')
	matrix LRbounds = e(LRbounds)
	local LBci = LRbounds[1, 1]
	local LB   = LRbounds[1, 2]
	local UB   = LRbounds[1, 3]
	local UBci = LRbounds[1, 4]
	replace lCI   = `LBci'  in `j'
	replace uCI   = `UBci'  in `j'
	replace LB = `LB' in `j'
	replace UB = `UB' in `j'
	replace estimator = `j' in `j'
	local ++j	
	local j = `j' + 1
	
}


format UB LB point %9.2g
generate posU = 9
generate posL = 9
twoway rcap lCI uCI     estimator in 1/9, scheme(s1mono) ///
 ||    scatter point    estimator in 1/9, ms(O)  mcolor(gs10) mlabel(point) ///
 ||    scatter UB       estimator in 1/9, ms(Oh) mcolor(gs5) mlabel(UB) mlabv(posU)  ///
 ||    scatter LB       estimator in 1/9, ms(Oh) mcolor(gs5) mlabel(LB) mlabv(posL) ///
xlabel(1 "OLS" ///
       2 "IV"   3 "NR (wo A4)" 4  "NR (A4)" ///
	   6 "OLS" ///
	   7 "IV"   8 "NR (wo A4)" 9  "NR (A4)" , ///
		angle(45)) xsize(8) xtitle("") ///
yline(0, lcolor(red) lpattern(dash) lwidth(thin)) ///
text(0.05 3.5 "Girls") text(0.05 7.5 "Boys") ///
legend(order(1 "95% CI" 2 "Point estimate" 3 "Bound Estimate") rows(1)) ytitle("Weight Penalty (z-BMI)") ///
ylabel(-0.09(0.05)0.07) 
graph export "$out/bound-nevo.eps", replace	

* Results for Obese
drop point lCI uCI estimator LB* UB* lCInevo* uCInevo* posU posL
gen point = .
gen estimator = .
gen lCI =. 
gen uCI =. 
gen LB = .
gen UB = .
gen lCInevo =. 
gen uCInevo =. 


local contr $contr
local sample flag3 == 1
local se cluster folio
local x T_95
local z nLbmi_care
local j = 1

foreach c of numlist 0 1 {
	* OLS 
	reg    lcbcl_t `contr' `x' if `sample' & sexchild == `c', vce(`se')
	local beta    		= _b[`x']
	local lCI     		= _b[`x']+invnormal(0.025)*_se[`x']
	local uCI     		= _b[`x']+invnormal(0.975)*_se[`x']
	replace point 		= `beta' in `j'
	replace lCI   		= `lCI'  in `j'
	replace uCI       	= `uCI'  in `j'
	replace estimator	= `j' in `j'
	local ++j
	
	* IV
	ivregress 2sls  lcbcl_t `contr' (`x' = `z')  if `sample' & sexchild == `c',  vce(`se')
	local betaiv = _b[`x']
	local lCIiv  = _b[`x']+invnormal(0.025)*_se[`x']
	local uCIiv  = _b[`x']+invnormal(0.975)*_se[`x']
	replace point = `betaiv' in `j'
	replace lCI   = `lCIiv'  in `j'
	replace uCI   = `uCIiv'  in `j'
	replace estimator = `j' in `j'
	local ++j
    
	* N&R no A4
    imperfectiv lcbcl_t `contr'  (`x' = `z')   if `sample' & sexchild == `c', vce(`se')  noassumption4
	matrix LRbounds = e(LRbounds)
	local LBci = LRbounds[1, 1]
	local LB   = LRbounds[1, 2]
	local UB   = LRbounds[1, 3]
	local UBci = LRbounds[1, 4]
	replace lCI   = `LBci'  in `j'
	replace uCI   = `UBci'  in `j'
	replace LB = `LB' in `j'
	replace UB = `UB' in `j'
	replace estimator = `j' in `j'
	local ++j
    
	* N&R with A4
	imperfectiv lcbcl_t `contr'  (`x' = `z')   if `sample' & sexchild == `c', vce(`se')
	matrix LRbounds = e(LRbounds)
	local LBci = LRbounds[1, 1]
	local LB   = LRbounds[1, 2]
	local UB   = LRbounds[1, 3]
	local UBci = LRbounds[1, 4]
	replace lCI   = `LBci'  in `j'
	replace uCI   = `UBci'  in `j'
	replace LB = `LB' in `j'
	replace UB = `UB' in `j'
	replace estimator = `j' in `j'
	local ++j	
	local j = `j' + 1
	
}


format UB LB point %9.2g
generate posU = 9
generate posL = 9
twoway rcap lCI uCI     estimator in 1/9, scheme(s1mono) ///
 ||    scatter point    estimator in 1/9, ms(O)  mcolor(gs10) mlabel(point) ///
 ||    scatter UB       estimator in 1/9, ms(Oh) mcolor(gs5) mlabel(UB) mlabv(posU)  ///
 ||    scatter LB       estimator in 1/9, ms(Oh) mcolor(gs5) mlabel(LB) mlabv(posL) ///
xlabel(1 "OLS" ///
       2 "IV"   3 "NR (wo A4)" 4  "NR (A4)" ///
	   6 "OLS" ///
	   7 "IV"   8 "NR (wo A4)" 9  "NR (A4)" , ///
		angle(45)) xsize(8) xtitle("") ///
yline(0, lcolor(red) lpattern(dash) lwidth(thin)) ///
text(0.05 3 "Girls") text(0.05 7 "Boys") ///
legend(order(1 "95% CI" 2 "Point estimate" 3 "Bound Estimate") rows(1)) ytitle("Weight penalty (obesity)") ///
ylabel(-0.7(0.1)0.1) 
graph export "$out/bound-nevo2.eps", replace			

*==================================================*
* Figure 5: Weight penalty by gender and age: 95% CI
*==================================================*

*Globals for controls: with potentially endogenous variables
global child "agechild c.agechild#c.agechild nolders nyounger" 
global house "i.region hsize"
global care  "i.hhead i.civil2 age_care cesd10_int dep_post lninc sch_care smoke drink2 drug2"


local sample flag3 == 1 & sexchild == 1
local se cluster(folio)
local base $child $house $care

ivreg2  lcbcl_t i.wave `base' (i.T_95 i.T_95#c.agechild = L.bmi_care c.L.bmi_care#c.agechild c.L.bmi_care#c.L.bmi_care) if `sample', `se' first
eststo boys: margins, dydx(T_95) at(agechild =(2(1)12)) post

local sample flag3 == 1 & sexchild == 0
local se cluster(folio)
local base $child $house $care

ivreg2  lcbcl_t  i.wave `base' (i.T_95 i.T_95#c.agechild = L.zbmi_care c.L.bmi_care#c.agechild c.L.bmi_care#c.L.bmi_care) if `sample', `se' first
eststo girls: margins, dydx(T_95) at(agechild =(2(1)12)) post

coefplot boys girls, vertical ///
	yline(0) mlabel format(%9.2g) mlabposition(12) mlabgap(*2) scheme(s1mono) ///
	ytitle("Weight penalty (Obesity)") xtitle("Age") ///
	xlabel(1 "2" 2 "3" 3 "4" 4 "5" 5 "6" 6 "7" 7 "8" 8 "9" 9 "10" 10 "11" 11 "12") ///
	title("B: Obesity as bodyweight")
graph save "$out/het-iv1", replace

	
local sample flag3 == 1 & sexchild == 1
local se cluster(folio)
local base $child $house $care

ivreg2  lcbcl_t i.wave `base' (c.zbmi_child c.zbmi_child#c.agechild = L.bmi_care c.L.bmi_care#c.agechild c.L.bmi_care#c.L.bmi_care) if `sample', `se' first
eststo boys: margins, dydx(zbmi_child) at(agechild =(2(1)12)) post

local sample flag3 == 1 & sexchild == 0
local se cluster(folio)
local base $child $house $care

ivreg2  lcbcl_t i.wave `base' (c.zbmi_child c.zbmi_child#c.agechild = L.zbmi_care c.L.bmi_care#c.agechild c.L.bmi_care#c.L.bmi_care) if `sample', `se' first
eststo girls: margins, dydx(zbmi_child) at(agechild =(2(1)12)) post

coefplot boys girls, vertical ///
	yline(0) mlabel format(%9.2g) mlabposition(12) mlabgap(*2) scheme(s1mono) ///
	ytitle("Weight penanlty (z-BMI)") xtitle("Age") ///
	xlabel(1 "2" 2 "3" 3 "4" 4 "5" 5 "6" 6 "7" 7 "8" 8 "9" 9 "10" 10 "11" 11 "12") ///
	title("A: z-BMI as bodyweight")
graph save "$out/het-iv2", replace
			
gr combine "$out/het-iv2" "$out/het-iv1", row(1) iscale(0.5)
graph export "$out/het.eps", replace
	
*==================================================*
*  Table 5: Potential mechanisms: IV estimates
*==================================================*

*Globals for controls: with potentially endogenous variables
global child "agechild c.agechild#c.agechild nolders nyounger" 
global house "i.region hsize"
global care  "i.hhead i.civil2 age_care cesd10_int dep_post lninc sch_care smoke drink2 drug2"

reg lcbcl_t $child $house $care zbmi_child Lbmi_care obs_ill tae_apariencia eclis_total if wave == 3
gen flag4 = 1 if e(sample)


local sample flag4 == 1
local se vce(cluster folio)
local base $child $house $care
local x zbmi_child 
local z Lbmi_care
est clear
foreach c of numlist 0 1 {
	eststo: ivregress 2sls lcbcl_t  `base' (`x' = `z')     if `sample' & sexchild == `c', `se' first
	scalar base = _b[`x']
	estat firststage, all
	mat fstat = r(singleresults)
	estadd scalar weak_F = fstat[1,4]
	estat endogenous
	estadd scalar Fendo  = r(regF)
	estadd scalar pFendo = r(p_regF)
	
	eststo: ivregress 2sls lcbcl_t  `base' eclis_total  (`x' = `z')     if `sample' & sexchild == `c', `se' first
	estat firststage, all
	mat fstat = r(singleresults)
	estadd scalar weak_F = fstat[1,4]
	estat endogenous
	estadd scalar Fendo  = r(regF)
	estadd scalar pFendo = r(p_regF)
	scalar new          = _b[`x']
    estadd scalar share = (base - new) / base * 100
	
	
	eststo: ivregress 2sls lcbcl_t  `base' obs_ill (`x' = `z')     if `sample' & sexchild == `c', `se' first
	estat firststage, all
	mat fstat = r(singleresults)
	estadd scalar weak_F = fstat[1,4]
	estat endogenous
	estadd scalar Fendo  = r(regF)
	estadd scalar pFendo = r(p_regF)
	scalar new          = _b[`x']
    estadd scalar share = (base - new) / base * 100
	
	eststo: ivregress 2sls lcbcl_t  `base' tae_apariencia (`x' = `z')     if `sample' & sexchild == `c', `se' first
	estat firststage, all
	mat fstat = r(singleresults)
	estadd scalar weak_F = fstat[1,4]
	estat endogenous
	estadd scalar Fendo  = r(regF)
	estadd scalar pFendo = r(p_regF)
	scalar new          = _b[`x']
    estadd scalar share = (base - new) / base * 100
	
	
	eststo: ivregress 2sls lcbcl_t  `base' eclis_total obs_ill tae_apariencia (`x' = `z')     if `sample' & sexchild == `c', `se' first
	estat firststage, all
	mat fstat = r(singleresults)
	estadd scalar weak_F = fstat[1,4]
	estat endogenous
	estadd scalar Fendo  = r(regF)
	estadd scalar pFendo = r(p_regF)
	scalar new          = _b[`x']
    estadd scalar share = (base - new) / base * 100
	
}


esttab using "$out/cbcl-full-balanced-mechanisms.tex", replace f ///
	b(%-9.3f) se(%-9.3f) star(* 0.10 ** 0.05 *** 0.01) ///
	keep(zbmi_child obs_ill tae_apariencia eclis_total) coeflabel(zbmi_child "Weight penalty" tae_apariencia "BI satisfaction"  eclis_total "Bullying" obs_ill "Bad health") ///
	substitute(\_ _) ///
	booktabs nonotes collabels(none) alignment(D{.}{.}{-1}) longtable nolines posthead(\hline \textbf{Panel A: z-BMI as bodyweight measure} \\) compress nogap nodepvar nomtitle ///
	stats(weak_F share N, fmt(%-9.3f %-9.0f %9.0gc) label("F first-stage" "\shortstack[l]{\% Reduction \\ in bodyweight \\ coefficient}" "N")) ///
   mgroups("Girls" "Boys", pattern(1 0 0 0 0 1 0 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
	
local sample flag4 == 1
local se vce(cluster folio)
local base i.wave $child $house $care
local x T_95 
local z Lbmi_care
est clear
foreach c of numlist 0 1 {
	eststo: ivregress 2sls lcbcl_t  `base' (`x' = `z')     if `sample' & sexchild == `c', `se' first
	scalar base = _b[`x']
	estat firststage, all
	mat fstat = r(singleresults)
	estadd scalar weak_F = fstat[1,4]
	estat endogenous
	estadd scalar Fendo  = r(regF)
	estadd scalar pFendo = r(p_regF)
	
	eststo: ivregress 2sls lcbcl_t  `base' eclis_total (`x' = `z')     if `sample' & sexchild == `c', `se' first
	estat firststage, all
	mat fstat = r(singleresults)
	estadd scalar weak_F = fstat[1,4]
	estat endogenous
	estadd scalar Fendo  = r(regF)
	estadd scalar pFendo = r(p_regF)
	scalar new          = _b[`x']
    estadd scalar share = (base - new) / base * 100
	
	eststo: ivregress 2sls lcbcl_t  `base' obs_ill (`x' = `z')     if `sample' & sexchild == `c', `se' first
	estat firststage, all
	mat fstat = r(singleresults)
	estadd scalar weak_F = fstat[1,4]
	estat endogenous
	estadd scalar Fendo  = r(regF)
	estadd scalar pFendo = r(p_regF)
	scalar new          = _b[`x']
    estadd scalar share = (base - new) / base * 100
	
	eststo: ivregress 2sls lcbcl_t  `base' tae_apariencia (`x' = `z')     if `sample' & sexchild == `c', `se' first
	estat firststage, all
	mat fstat = r(singleresults)
	estadd scalar weak_F = fstat[1,4]
	estat endogenous
	estadd scalar Fendo  = r(regF)
	estadd scalar pFendo = r(p_regF)
		scalar new          = _b[`x']
    estadd scalar share = (base - new) / base * 100
	
	eststo: ivregress 2sls lcbcl_t  `base' eclis_total obs_ill tae_apariencia (`x' = `z')     if `sample' & sexchild == `c', `se' first
	estat firststage, all
	mat fstat = r(singleresults)
	estadd scalar weak_F = fstat[1,4]
	estat endogenous
	estadd scalar Fendo  = r(regF)
	estadd scalar pFendo = r(p_regF)
	scalar new          = _b[`x']
    estadd scalar share = (base - new) / base * 100
}	
esttab using "$out/cbcl-full-balanced-mechanisms.tex", append f ///
	b(%-9.3f) se(%-9.3f) star(* 0.10 ** 0.05 *** 0.01) ///
    	keep(T_95 obs_ill tae_apariencia eclis_total) coeflabel(T_95 "Weight penalty" tae_apariencia "BI satisfaction" eclis_total "Bullying" obs_ill "Bad health") ///
	substitute(\_ _) ///
	label booktabs nonotes collabels(none) alignment(D{.}{.}{-1}) longtable nomtitle nolines nonum posthead(\hline \textbf{Panel B: Obesity as bodyweight measure} \\)  compress nogap ///
	stats(weak_F share N, fmt(%-9.3f %-9.0f %9.0gc) label("F first-stage" "\shortstack[l]{\% Reduction \\ in bodyweight \\ coefficient}" "N")) 
	
************ END ********************


	 
